@@ -11,9 +11,8 @@ use Scalar::Util qw(blessed);
 use Form::Tiny::Form;
 use Form::Tiny::Utils qw(trim :meta_handlers);
 require Moo;
-require Moo::Role;
 
-our $VERSION = '2.06';
+our $VERSION = '2.07';
 
 sub import
 {
@@ -30,8 +29,6 @@ sub import
 	}
 
 	$package->ft_install($caller, @wanted);
-
-	Moo::Role->apply_roles_to_package($caller, __PACKAGE__);
 	return;
 }
 
@@ -200,19 +197,6 @@ sub _get_flag
 	return;
 }
 
-# role to add form_meta method
-
-use Moo::Role;
-
-sub form_meta
-{
-	my ($self) = @_;
-	my $package = defined blessed $self ? blessed $self : $self;
-
-	return get_package_form_meta($package);
-}
-
-
 1;
 
 __END__
