@@ -12,7 +12,7 @@ use Form::Tiny::Error;
 use Form::Tiny::Utils qw(try get_package_form_meta);
 use Moo::Role;
 
-our $VERSION = '2.06';
+our $VERSION = '2.07';
 
 has 'field_defs' => (
 	is => 'ro',
@@ -56,7 +56,7 @@ has 'valid' => (
 	isa => Bool,
 	lazy => 1,
 	builder => '_ft_validate',
-	clearer => 1,
+	clearer => 'clear_valid',
 	predicate => 'is_validated',
 	init_arg => undef,
 );
